"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.scanFromBitmap = void 0;
var error_1 = __importDefault(require("../handlers/error"));
var qrcode_reader_1 = __importDefault(require("../infrastructure/qrcode-reader"));
var flags_1 = require("../handlers/flags");
/**
 * You can pass a jimp Bitmap, this functions reads it's content and tries to find a QR Code, returning it's result
 * ```javascript
 * import Jimp from 'jimp'
 *
 * const bitmap = Jimp.read('./image.jpg')
 * const value = await scanFromBitmap(bitmap)
 * ```
 *
 * @param bitmap A Bitmap object
 * @param flags
 * @returns Value read from the QR Code inside the image
 */
var scanFromBitmap = function (bitmap, flags) {
    return Promise.resolve(bitmap)
        .then(qrcode_reader_1.default)
        .then(flags_1.doFlagClipboard(flags || {}))
        .then(flags_1.doOpen(flags || {}))
        .catch(error_1.default.scanFromBitmap);
};
exports.scanFromBitmap = scanFromBitmap;
